import com.aspose.metafiles.*;
import com.sun.media.jai.codec.BMPEncodeParam;
import com.sun.media.jai.codec.ImageCodec;
import com.sun.media.jai.codec.ImageEncoder;
import java.awt.Color;
import java.awt.Graphics2D;
import java.awt.Rectangle;
import java.awt.RenderingHints;
import java.awt.geom.AffineTransform;
import java.awt.image.BufferedImage;
import java.awt.image.RenderedImage;
import java.io.*;
import java.util.HashMap;
import java.util.Map;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

import javax.naming.directory.DirContext;

/**
 * This demo shows how to convert all Emf metafiles in
 * the current directory to PNG image format.
 *
 */
public class emf2png
{

    static private class EmfFilter implements FilenameFilter {

        EmfFilter(String pattern) {
            pat = pattern;
        }

        public boolean accept (File dir, String name) {
            return Pattern.matches(pat, name);
        }

        String pat;
    }

    public static void main(String[] args) throws Throwable {

        try {

            File dir = new File(".");
            EmfFilter filter = new EmfFilter(".*\\.emf$");
            File[] files = dir.listFiles(filter);

            for(int i = 0; i < files.length; i++)
                if(files[i].canRead() && files[i].isFile())
                    processImage(files[i].getAbsolutePath());

        } catch(MetafilesException me) {
        }
    }
    
    static void processImage(String fileName) throws Exception {

        // Read Emf metafile from file
        FileInputStream file = new FileInputStream(fileName); 
        EmfMetafile efile = new EmfMetafile(file);
        System.out.println("Reading file " + fileName);

        // Create image on memory
        BufferedImage image = new BufferedImage((int)(efile.getWidth() + 0.5),
            (int)(efile.getHeight() + 0.5), BufferedImage.TYPE_3BYTE_BGR);
        Graphics2D graphics = image.createGraphics();

        // Define rendering hints to make all lines and text antialiased        
        Map map = new HashMap();
        map.put(RenderingHints.KEY_ANTIALIASING, RenderingHints.VALUE_ANTIALIAS_ON);
        map.put(RenderingHints.KEY_TEXT_ANTIALIASING, RenderingHints.VALUE_TEXT_ANTIALIAS_ON);
        graphics.addRenderingHints(map);
        efile.setDefaultRenderingHints((RenderingHints)graphics.getRenderingHints().clone());
        
        RenderedImage rima = efile.createDefaultRendering();

        // Draw metafile on created image
        graphics.setPaint(Color.WHITE);
        graphics.fill(new Rectangle(0, 0, image.getWidth(),
                image.getHeight()));
        efile.playMetafile(graphics);
        String outName = fileName + ".png";

        // Save created image to PNG file using JAI-IO library
        FileOutputStream stream = new FileOutputStream(outName);
        PNGEncodeParam param = new PNGEncodeParam();
        ImageEncoder enc = ImageCodec.createImageEncoder("PNG", stream, param);
        enc.encode(image);
        stream.close();
    }
}
